window.Gleam.initSearch([{"doc":"galant","title":"galant","content":"# galant\n\n[![Package Version](https://img.shields.io/hexpm/v/galant)](https://hex.pm/packages/galant)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/galant/)\n\n A Gleam library for creating colored and decorated strings for the terminal using ANSI Escape Sequences\n\n## Installation\n\nTo install from Hex\n\n```sh\ngleam add galant\n```\n\nDocumentation can be found at &lt;https://hexdocs.pm/galant&gt;.\n\n## Overview\n\ngalant is a Gleam library that creates colored and decorated strings for the terminal. It has a fluent API which can be composed for matching various use-cases. Here is a simple example of how a styled string can be created.\n\n```gleam\nopen()\n|&gt; text(&quot;Basic &quot;)\n|&gt; start_bold()\n|&gt; magenta(&quot;galant&quot;)\n|&gt; end_bold()\n|&gt; text(&quot; example&quot;)\n|&gt; to_string()\n|&gt; io.println()\n```\n\n&gt;&lt;span style=&quot;color:white&quot;&gt;Basic &lt;/span&gt;&lt;span style=&quot;color:magenta&quot;&gt;galant&lt;/span&gt;&lt;span style=&quot;color:white&quot;&gt; example&lt;/span&gt;\n\n## Usage\n\ngalant supports some different options for coloring and styling text for the terminal using `ANSI Escape Sequences`. The most direct way is to use the various text-styling functions to create a styling sequence that can be transformed into a styled string. This method introduces the basic api and is the basic building block which can be used to compose reusable element later on.\n\nThe `open()` function can be used to start a new styling sequence and is followed by one or more styling functions. The sequence can be terminated with a call to `to_string()` which will produce a string with the relevant `ANSI Escape Sequences`.\n\n```gleam\n  open()\n  |&gt; green(&quot;I&#39;m the mighty frog&quot;)\n  |&gt; to_string()\n  |&gt; io.println()\n```\n&gt; &lt;span style=&quot;color:green&quot;&gt;I&#39;m the mighty frog&lt;/span&gt;\n\nTo add color and decoration to a piece of text the `start_{color/decoration}` functions can be used. For decorations there also exists a corresponding `end_{decoration}` function which is useful for decorating only parts of a text. These functions can be used in conjunction with the `text(String)` function which will insert a piece of text in the styling sequence.\n\n```gleam\nopen()\n|&gt; start_yellow()\n|&gt; start_bold()\n|&gt; text(&quot;I&#39;m a very bold lemon &quot;)\n|&gt; end_bold()\n|&gt; text(&quot;and I&#39;m normal banana&quot;)\n|&gt; to_string()\n|&gt; io.println()\n```\n\n&gt; &lt;span style=&quot;color:yellow;font-weight:bold&quot;&gt;I&#39;m a very bold lemon &lt;span style=&quot;font-weight:normal&quot;&gt;and I&#39;m a normal banana&lt;/span&gt;&lt;/span&gt;\n\nFurthermore styling sequences can be captured by replacing the `to_string()` with the `save()` function and utilizing the `placeholder()` function somewhere in the sequence. This will return a style-function that takes one `String` argument and can then be used in other styling sequences to style a string accordingly.\n\n```gleam\nlet party_style =\n  open()\n  |&gt; start_magenta()\n  |&gt; start_italic()\n  |&gt; start_underline()\n  |&gt; placeholder()\n  |&gt; save()\n\nopen()\n|&gt; text(&quot;Welcome to &quot;)\n|&gt; party_style(&quot;the party!!&quot;)\n|&gt; to_string()\n|&gt; io.println()\n```\n\n&gt; Welcome to &lt;span style=&quot;color:magenta;font-style:italic;text-decoration:underline&quot;&gt;the party!!&lt;/span&gt;\n\nFinally the same principle as with `save()` can be used but with `to_string_styler()` on a sequence with a placeholder. This will create a function that can be applied to a string to directly style it without the need to include it in another styling sequence.\n\n```gleam\nI&#39;m not very good at &quot; &lt;&gt; correction(&quot;speling&quot;) &lt;&gt; &quot; all the &quot; &lt;&gt; correction(&quot;wurds&quot;)\n```\n\n&gt; I&#39;m not very good at &lt;span style=&quot;color:red;text-decoration:line-through&quot;&gt;speling&lt;/span&gt; all the &lt;span style=&quot;color:red;text-decoration:line-through&quot;&gt;wurds&lt;/span&gt;\n\n## Colors\nThe 8 standard colors black, white, red, green, blue, magenta and cyan all have their corresponding named functions.\n\nIf you target terminal supports 256 colors or RGB (Truecolor) colors can be applied with the same principles using the `color_256` (for 256 colors) and `color_rgb`/`color_hex` functions.\n\n```gleam\nopen()\n|&gt; text(&quot;In Xterm this color is called &quot;)\n|&gt; color_256(&quot;DarkOrange3&quot;, 166)\n|&gt; to_string()\n|&gt; io.println()\n```\n\n&gt; In Xterm this color is called&gt; &lt;span style=&quot;color:rgb(175,95,0)&quot;&gt;DarkOrange3&lt;/span&gt;\n\n```gleam\nopen()\n|&gt; text(&quot;A pastel palette\\n&quot;)\n|&gt; color_bg_rgb(&quot;     &quot;, 231, 231, 238)\n|&gt; color_bg_hex(&quot;     &quot;, 0xE9FAE3)\n|&gt; color_bg_hex(&quot;     &quot;, 0xDEE8D5)\n|&gt; color_bg_hex(&quot;     &quot;, 0xD5C7BC)\n|&gt; color_bg_rgb(&quot;     &quot;, 172, 146, 166)\n|&gt; to_string()\n|&gt; io.println()\n```\n\n&gt; A pastel palette\n&gt;\n&gt; &lt;span style=&quot;background-color:rgb(231,231,238)&quot;&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;/span&gt;&lt;span style=&quot;background-color:#E9FAE3&quot;&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;/span&gt;&lt;span style=&quot;background-color:#DEE8D5&quot;&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;/span&gt;&lt;span style=&quot;background-color:#D5C7BC&quot;&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;/span&gt;&lt;span style=&quot;background-color:rgb(172,146,166)&quot;&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;/span&gt;\n\n## Text decoration\nText decorations have their own named functions, like `bold` and `italic` and few more. Beware that not all decorations may be supported in all terminals.","url":"index.html"},{"doc":"galant","title":"StyledTextPart","content":"pub opaque type StyledTextPart\n The StyledTextPart type is used to represent all the different parts of a styled sequence.\n Normally this type is not expected to be used outside the library but it is exposed by all\n the styling functions since this is part of the return type.\n\nSynonyms:\ngalant.StyledTextPart\ngalant StyledTextPart","url":"galant.html#StyledTextPart"},{"doc":"galant","title":"bg_black","content":"pub fn bg_black(styled_text: List(StyledTextPart), text: String) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.bg_black\ngalant bg_black","url":"galant.html#bg_black"},{"doc":"galant","title":"bg_blue","content":"pub fn bg_blue(styled_text: List(StyledTextPart), text: String) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.bg_blue\ngalant bg_blue","url":"galant.html#bg_blue"},{"doc":"galant","title":"bg_cyan","content":"pub fn bg_cyan(styled_text: List(StyledTextPart), text: String) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.bg_cyan\ngalant bg_cyan","url":"galant.html#bg_cyan"},{"doc":"galant","title":"bg_default","content":"pub fn bg_default(styled_text: List(StyledTextPart), text: String) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.bg_default\ngalant bg_default","url":"galant.html#bg_default"},{"doc":"galant","title":"bg_green","content":"pub fn bg_green(styled_text: List(StyledTextPart), text: String) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.bg_green\ngalant bg_green","url":"galant.html#bg_green"},{"doc":"galant","title":"bg_magenta","content":"pub fn bg_magenta(styled_text: List(StyledTextPart), text: String) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.bg_magenta\ngalant bg_magenta","url":"galant.html#bg_magenta"},{"doc":"galant","title":"bg_red","content":"pub fn bg_red(styled_text: List(StyledTextPart), text: String) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.bg_red\ngalant bg_red","url":"galant.html#bg_red"},{"doc":"galant","title":"bg_white","content":"pub fn bg_white(styled_text: List(StyledTextPart), text: String) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.bg_white\ngalant bg_white","url":"galant.html#bg_white"},{"doc":"galant","title":"bg_yellow","content":"pub fn bg_yellow(styled_text: List(StyledTextPart), text: String) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.bg_yellow\ngalant bg_yellow","url":"galant.html#bg_yellow"},{"doc":"galant","title":"black","content":"pub fn black(styled_text: List(StyledTextPart), text: String) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.black\ngalant black","url":"galant.html#black"},{"doc":"galant","title":"blinking","content":"pub fn blinking(styled_text: List(StyledTextPart), text: String) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.blinking\ngalant blinking","url":"galant.html#blinking"},{"doc":"galant","title":"blue","content":"pub fn blue(styled_text: List(StyledTextPart), text: String) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.blue\ngalant blue","url":"galant.html#blue"},{"doc":"galant","title":"bold","content":"pub fn bold(styled_text: List(StyledTextPart), text: String) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.bold\ngalant bold","url":"galant.html#bold"},{"doc":"galant","title":"color_256","content":"pub fn color_256(styled_text: List(StyledTextPart), text: String, color: Int) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.color_256\ngalant color_256","url":"galant.html#color_256"},{"doc":"galant","title":"color_bg_hex","content":"pub fn color_bg_hex(styled_text: List(StyledTextPart), text: String, color: Int) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.color_bg_hex\ngalant color_bg_hex","url":"galant.html#color_bg_hex"},{"doc":"galant","title":"color_bg_rgb","content":"pub fn color_bg_rgb(styled_text: List(StyledTextPart), text: String, red: Int, green: Int, blue: Int) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.color_bg_rgb\ngalant color_bg_rgb","url":"galant.html#color_bg_rgb"},{"doc":"galant","title":"color_hex","content":"pub fn color_hex(styled_text: List(StyledTextPart), text: String, color: Int) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.color_hex\ngalant color_hex","url":"galant.html#color_hex"},{"doc":"galant","title":"color_rgb","content":"pub fn color_rgb(styled_text: List(StyledTextPart), text: String, red: Int, green: Int, blue: Int) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.color_rgb\ngalant color_rgb","url":"galant.html#color_rgb"},{"doc":"galant","title":"cyan","content":"pub fn cyan(styled_text: List(StyledTextPart), text: String) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.cyan\ngalant cyan","url":"galant.html#cyan"},{"doc":"galant","title":"default","content":"pub fn default(styled_text: List(StyledTextPart), text: String) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.default\ngalant default","url":"galant.html#default"},{"doc":"galant","title":"dim","content":"pub fn dim(styled_text: List(StyledTextPart), text: String) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.dim\ngalant dim","url":"galant.html#dim"},{"doc":"galant","title":"end_blinking","content":"pub fn end_blinking(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.end_blinking\ngalant end_blinking","url":"galant.html#end_blinking"},{"doc":"galant","title":"end_bold","content":"pub fn end_bold(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.end_bold\ngalant end_bold","url":"galant.html#end_bold"},{"doc":"galant","title":"end_dim","content":"pub fn end_dim(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.end_dim\ngalant end_dim","url":"galant.html#end_dim"},{"doc":"galant","title":"end_hidden","content":"pub fn end_hidden(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.end_hidden\ngalant end_hidden","url":"galant.html#end_hidden"},{"doc":"galant","title":"end_inverse","content":"pub fn end_inverse(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.end_inverse\ngalant end_inverse","url":"galant.html#end_inverse"},{"doc":"galant","title":"end_italic","content":"pub fn end_italic(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.end_italic\ngalant end_italic","url":"galant.html#end_italic"},{"doc":"galant","title":"end_strikethrough","content":"pub fn end_strikethrough(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.end_strikethrough\ngalant end_strikethrough","url":"galant.html#end_strikethrough"},{"doc":"galant","title":"end_underline","content":"pub fn end_underline(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.end_underline\ngalant end_underline","url":"galant.html#end_underline"},{"doc":"galant","title":"green","content":"pub fn green(styled_text: List(StyledTextPart), text: String) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.green\ngalant green","url":"galant.html#green"},{"doc":"galant","title":"hidden","content":"pub fn hidden(styled_text: List(StyledTextPart), text: String) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.hidden\ngalant hidden","url":"galant.html#hidden"},{"doc":"galant","title":"inverse","content":"pub fn inverse(styled_text: List(StyledTextPart), text: String) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.inverse\ngalant inverse","url":"galant.html#inverse"},{"doc":"galant","title":"italic","content":"pub fn italic(styled_text: List(StyledTextPart), text: String) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.italic\ngalant italic","url":"galant.html#italic"},{"doc":"galant","title":"magenta","content":"pub fn magenta(styled_text: List(StyledTextPart), text: String) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.magenta\ngalant magenta","url":"galant.html#magenta"},{"doc":"galant","title":"open","content":"pub fn open() -&gt; List(a)\n Start a new styled sequence\nSynonyms:\ngalant.open\ngalant open","url":"galant.html#open"},{"doc":"galant","title":"placeholder","content":"pub fn placeholder(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.placeholder\ngalant placeholder","url":"galant.html#placeholder"},{"doc":"galant","title":"red","content":"pub fn red(styled_text: List(StyledTextPart), text: String) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.red\ngalant red","url":"galant.html#red"},{"doc":"galant","title":"reset","content":"pub fn reset(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.reset\ngalant reset","url":"galant.html#reset"},{"doc":"galant","title":"save","content":"pub fn save(this_styled_text: List(StyledTextPart)) -&gt; fn(\n  List(StyledTextPart),\n  String,\n) -&gt; List(StyledTextPart)\n\nSynonyms:\ngalant.save\ngalant save","url":"galant.html#save"},{"doc":"galant","title":"start_bg_black","content":"pub fn start_bg_black(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.start_bg_black\ngalant start_bg_black","url":"galant.html#start_bg_black"},{"doc":"galant","title":"start_bg_blue","content":"pub fn start_bg_blue(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.start_bg_blue\ngalant start_bg_blue","url":"galant.html#start_bg_blue"},{"doc":"galant","title":"start_bg_color_hex","content":"pub fn start_bg_color_hex(styled_text: List(StyledTextPart), color: Int) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.start_bg_color_hex\ngalant start_bg_color_hex","url":"galant.html#start_bg_color_hex"},{"doc":"galant","title":"start_bg_color_rgb","content":"pub fn start_bg_color_rgb(styled_text: List(StyledTextPart), red: Int, green: Int, blue: Int) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.start_bg_color_rgb\ngalant start_bg_color_rgb","url":"galant.html#start_bg_color_rgb"},{"doc":"galant","title":"start_bg_cyan","content":"pub fn start_bg_cyan(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.start_bg_cyan\ngalant start_bg_cyan","url":"galant.html#start_bg_cyan"},{"doc":"galant","title":"start_bg_green","content":"pub fn start_bg_green(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.start_bg_green\ngalant start_bg_green","url":"galant.html#start_bg_green"},{"doc":"galant","title":"start_bg_magenta","content":"pub fn start_bg_magenta(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.start_bg_magenta\ngalant start_bg_magenta","url":"galant.html#start_bg_magenta"},{"doc":"galant","title":"start_bg_red","content":"pub fn start_bg_red(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.start_bg_red\ngalant start_bg_red","url":"galant.html#start_bg_red"},{"doc":"galant","title":"start_bg_white","content":"pub fn start_bg_white(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.start_bg_white\ngalant start_bg_white","url":"galant.html#start_bg_white"},{"doc":"galant","title":"start_bg_yellow","content":"pub fn start_bg_yellow(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.start_bg_yellow\ngalant start_bg_yellow","url":"galant.html#start_bg_yellow"},{"doc":"galant","title":"start_black","content":"pub fn start_black(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.start_black\ngalant start_black","url":"galant.html#start_black"},{"doc":"galant","title":"start_blinking","content":"pub fn start_blinking(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.start_blinking\ngalant start_blinking","url":"galant.html#start_blinking"},{"doc":"galant","title":"start_blue","content":"pub fn start_blue(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.start_blue\ngalant start_blue","url":"galant.html#start_blue"},{"doc":"galant","title":"start_bold","content":"pub fn start_bold(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.start_bold\ngalant start_bold","url":"galant.html#start_bold"},{"doc":"galant","title":"start_color_hex","content":"pub fn start_color_hex(styled_text: List(StyledTextPart), color: Int) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.start_color_hex\ngalant start_color_hex","url":"galant.html#start_color_hex"},{"doc":"galant","title":"start_color_rgb","content":"pub fn start_color_rgb(styled_text: List(StyledTextPart), red: Int, green: Int, blue: Int) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.start_color_rgb\ngalant start_color_rgb","url":"galant.html#start_color_rgb"},{"doc":"galant","title":"start_cyan","content":"pub fn start_cyan(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.start_cyan\ngalant start_cyan","url":"galant.html#start_cyan"},{"doc":"galant","title":"start_dim","content":"pub fn start_dim(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.start_dim\ngalant start_dim","url":"galant.html#start_dim"},{"doc":"galant","title":"start_green","content":"pub fn start_green(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.start_green\ngalant start_green","url":"galant.html#start_green"},{"doc":"galant","title":"start_hidden","content":"pub fn start_hidden(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.start_hidden\ngalant start_hidden","url":"galant.html#start_hidden"},{"doc":"galant","title":"start_inverse","content":"pub fn start_inverse(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.start_inverse\ngalant start_inverse","url":"galant.html#start_inverse"},{"doc":"galant","title":"start_italic","content":"pub fn start_italic(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.start_italic\ngalant start_italic","url":"galant.html#start_italic"},{"doc":"galant","title":"start_magenta","content":"pub fn start_magenta(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.start_magenta\ngalant start_magenta","url":"galant.html#start_magenta"},{"doc":"galant","title":"start_red","content":"pub fn start_red(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.start_red\ngalant start_red","url":"galant.html#start_red"},{"doc":"galant","title":"start_strikethrough","content":"pub fn start_strikethrough(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.start_strikethrough\ngalant start_strikethrough","url":"galant.html#start_strikethrough"},{"doc":"galant","title":"start_underline","content":"pub fn start_underline(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.start_underline\ngalant start_underline","url":"galant.html#start_underline"},{"doc":"galant","title":"start_white","content":"pub fn start_white(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.start_white\ngalant start_white","url":"galant.html#start_white"},{"doc":"galant","title":"start_yellow","content":"pub fn start_yellow(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.start_yellow\ngalant start_yellow","url":"galant.html#start_yellow"},{"doc":"galant","title":"stop_bg_color","content":"pub fn stop_bg_color(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.stop_bg_color\ngalant stop_bg_color","url":"galant.html#stop_bg_color"},{"doc":"galant","title":"stop_color","content":"pub fn stop_color(styled_text: List(StyledTextPart)) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.stop_color\ngalant stop_color","url":"galant.html#stop_color"},{"doc":"galant","title":"strikethrough","content":"pub fn strikethrough(styled_text: List(StyledTextPart), text: String) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.strikethrough\ngalant strikethrough","url":"galant.html#strikethrough"},{"doc":"galant","title":"text","content":"pub fn text(styled_text: List(StyledTextPart), text: String) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.text\ngalant text","url":"galant.html#text"},{"doc":"galant","title":"to_string","content":"pub fn to_string(styled_text: List(StyledTextPart)) -&gt; String\n\nSynonyms:\ngalant.to_string\ngalant to_string","url":"galant.html#to_string"},{"doc":"galant","title":"to_string_styler","content":"pub fn to_string_styler(this_styled_text: List(StyledTextPart)) -&gt; fn(\n  String,\n) -&gt; String\n\nSynonyms:\ngalant.to_string_styler\ngalant to_string_styler","url":"galant.html#to_string_styler"},{"doc":"galant","title":"underline","content":"pub fn underline(styled_text: List(StyledTextPart), text: String) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.underline\ngalant underline","url":"galant.html#underline"},{"doc":"galant","title":"white","content":"pub fn white(styled_text: List(StyledTextPart), text: String) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.white\ngalant white","url":"galant.html#white"},{"doc":"galant","title":"yellow","content":"pub fn yellow(styled_text: List(StyledTextPart), text: String) -&gt; List(\n  StyledTextPart,\n)\n\nSynonyms:\ngalant.yellow\ngalant yellow","url":"galant.html#yellow"},{"doc":"galant","title":"galant","content":"","url":"galant.html"}]);